.. Marke37 documentation master file, created by
   sphinx-quickstart on Thu Feb 11 19:45:15 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Marke37
===================================

*Marke37* es un lenguaje de marcado ligero diseñado para escribir letras de canciones, basado en sintaxis de los lenguajes como Markdown_, reStructuredText_, y Markua_, desarrollado por `Carlos Ramos`_ para facilitarse la vida mientras escribía letras para la banda a la que pertenece, experimento37_.

Su objetivo es brindar a los letristas un lenguaje fácil de utilizar para definir las secciones de las letras, así como diversos cambios o efectos en la voz, y comentarios adicionales.

A la vez, *Marke37* es un convertidor a diversos formatos, que permite que las letras escritas con este lenguaje de marcado puedan ser distribuidas como documentos HTML, PDF, o incluso ser mandadas como un mensaje de texto a través de plataformas como WhatsApp.

En este documento se describe tanto el estándar que permite crear letras de canciones con el formato *Marke37*, como el uso del convertidor para compartir las letras en formatos comunes, como HTML y PDF.

.. toctree::
   :maxdepth: 3
   :caption: Contenido

   especificación
   editor_en_linea
..   convertidor
..   errores
..   sublime
..   plantilla_html
..   pygments
..   directiva_sphinx

.. Documentación del código
.. ========================

.. .. toctree::
..    :maxdepth: 3
..    :caption: Contenido

..    codigo_linea

.. Indices and tables
.. ==================

.. * :ref:`genindex`
.. * :ref:`modindex`
.. * :ref:`search`

.. automodule:: letra.Letra

.. _Markdown: https://es.wikipedia.org/wiki/Markdown
.. _reStructuredText: https://es.wikipedia.org/wiki/ReStructuredText
.. _Markua: https://leanpub.com/markua/read
.. _Carlos Ramos: http://ramoscarlos.com/
.. _experimento37: http://e37.mx/